import '../common/description.dart';
import '../common/name.dart';
import '../common/named_api_resource.dart';
import '../common/named_api_resource_list.dart';
import '../../network/rest.dart';

///Item attributes define particular aspects of items, e.g. "usable in battle" or "consumable".
class ItemAttribute {
  int id;
  String name;
  List<NamedApiResource> items;
  List<Name> names;
  List<Description> descriptions;

  ItemAttribute.fromJson(Map<String, dynamic> json)
      : id = json['id'],
        name = json['name'],
        items = NamedApiResource.fromList(json['items']),
        names = Name.fromList(json['names']),
        descriptions = Description.fromList(json['descriptions']);

  static Future<ItemAttribute> get(String query) async =>
      ItemAttribute.fromJson(await RestConnection.get<ItemAttribute>(query));

  static Future<NamedApiResourceList> find(
          [int limit = 0, int skip = 0]) async =>
      NamedApiResourceList.fromJson(
          await RestConnection.find<ItemAttribute>(limit, skip));

  @override
  String toString() =>
      '$runtimeType {id: $id, name: $name, items: $items, names: $names, descriptions: $descriptions}';
}
